<CsoundSynthesizer>
<CsOptions>
-odac -Ma -b256 -B512 --midi-key=4 --midi-velocity-amp=5 -m0
</CsOptions>
<CsInstruments>
sr	= 44100
kr	= 441
nchnls = 2

/****************DEMONSTRACIJA RAZNOVRSNIH UGODBI GLAZBALA******************/
;;Prema edukacijskoj ideji akademika Nikše Gliga i kodnom predlošku 
;;    Joachima Heintza program napisao Stanko Juzbašić		
;;Skale su različite, kako po ugodbi, tako i po broju tonova u oktavi
;;Sve su skale oktavno simetrične
;;Izbornikom u grafičkom sučelju odabire se ugodba, odnosno skala
;;Sintetizator signala rabi Karplus-Strongov algoritam (trzanje strune)
;;    Ton C1 postavljen je na 261.6255 Hz što odgovara A1 = 440 Hz
/***************************************************************************/
;;DEFINICIJA TABLICA SKALA I UGODBI

;Skala 1: čista ugodba (12 po oktavi)
;param. : red.br, vrijeme, -broj članova, GEN_rutina(p4), <čl.1, čl.2, ..., čl.n>
giJust	ftgen 		1, 0, -12, -2,  0,  112, 204, 316, 386, 498, 610, 702, 814, 884, 996, 1088
;Skala 2: pitegorejska
giPyth	ftgen 		2, 0, -12, -2,  0, 90.22, 203.91, 294.13, 407.82, 498.04, 611.73, 701.96, 792.18, 905.87, 996.09, 1109.78
;Skala 3: srednjetonska 1/4 kome
giMeanTone	ftgen 		3, 0, -12, -2,  0, 76.05, 193.16, 310.27, 386.31, 503.42, 579.47, 696.58, 772.63, 889.74, 1006.85, 1082.89
;Skala 4: Werckmeister 3
giWerckm3 ftgen 			4, 0, -12, -2, 0, 90.2, 194.6, 294.1, 389.1, 498.0, 588.3, 697.3, 792.2, 891.8, 996.1, 1091.1
;Skala 5: Kirnberger 2
giKirn2	ftgen 		5, 0, -12, -2,  0, 90, 204, 294, 386, 498, 590, 702, 792, 895, 996, 1088
;Skala 6: Bach-Kellner
giBachK	ftgen			6, 0, -12, -2, 0, 90, 194.5, 294, 389,498, 588, 697, 792, 892, 996, 1091	
;Skala 7: jednako temperirani polustepeni (12 po oktavi)
giHalfTones	ftgen 		7, 0, -12, -2,  0, 100, 200, 300, 400, 500, 600, 700, 800, 900, 1000, 1100
;Skala 8: jednako temperirani trećinostepeni (18 po oktavi)
giThirTones	ftgen 		8, 0, -18, -2,  0, 66.67, 133.33, 200, 266.67, 333.33, 400, 466.67, 533.33, 600, 666.67, 733.33, 800, 866.67, 933.33, 1000, 1066.67, 1133.33
;Skala 9: četvrtstepeni (24 po oktavi)
giQuarTones 	ftgen 		9, 0, -24, -2,  0, 50, 100, 150, 200, 250, 300, 350, 400, 450, 500, 550, 600, 650, 700, 750, 800, 850, 900, 950, 1000, 1050, 1100, 1150
;Skala 10: indijska šruti (22 po oktavi)
giSruti	ftgen		10, 0, -22, -2,  0, 90, 112, 182, 203, 294, 316, 386, 407, 498, 519, 590, 612, 702, 792, 814, 884, 906, 996, 1017, 1088, 1110
;Skala 11: LaMonte Young (temeljni ton Es!)
giYoung ftgen			11, 0, -12, -2,  69, 42, 273, 300, 477, 504, 540, 771, 744, 975, 1002, 1038
;Skala 12: Ben Johnston (harmonici tona C)
giJohnst	ftgen			12, 0, -12, -2, 0, 105.0, 203.9, 297.5, 386.3, 470.8, 551.3, 702.0, 840.5, 905.9, 968.8, 1088.3
;Skala 13: Partch diamond (43 stepena po oktavi)
giPartch    ftgen 		13, 0, -43, -2, 0, 21.5, 53.2, 84.5, 111.7, 150.6, 165.0, 182.4, 203.9, 231.2, 266.9, 294.1, 315.6, 347.4, 386.3, 417.5, 435.1, 470.8, 498.0, 519.5, 551.3, 582.5, 617.5, 648.7, 680.5, 702.0, 729.2, 764.9, 782.5, 813.7, 852.6, 884.4, 905.9, 933.1, 968.8, 996.1, 1017.6, 1035.0, 1049.4, 1088.3, 1115.5, 1146.8, 1178.5
;Skala 14: indonezijski slendro (crne tipke + H) i pelog (preostale bijele tipke)
giSlenPel ftgen			14, 0, -12, -2, 35,	85,	230, 330, 400, 545, 392, 820, 820, 947, 947, 1060


		massign 	0, 1 ; informacija s bilo kojeg midi kanala pokrenuti će sintezu

instr 1
;;UČITAJ ULAZNE PODATKE IZ MIDI KLAVIJATURE I GRAFIČKOG SUČELJA
ikey		=		p4
ivel		=		p5
kreftone	invalue	"reftone"; bilo kojem broju midi note
ktunfreq	invalue	"tunfreq"; dodijelimo bilo koju frekvenciju
kscale	invalue	"scale"; odaberemo skalu iz izbornika
ireftone	=		i(kreftone)
itunfreq	=		i(ktunfreq)
iscale	=		i(kscale) + 1; izbornik 0 odabire skalu 1 itd.
;;RAČUN I SINTEZA
itablen	=		ftlen(iscale)
ioct 		= 		floor((p4 - ireftone) / itablen) ; oktavni položaj
indx1 	= 		(p4-ireftone) % itablen; ispravne vrijednosti > 0 ali negativne za < 0
indx 		= 		(indx1 < 0 ? itablen + indx1 : indx1); umjesto -1 dobijemo 17
icent1 	tab_i 	indx, iscale; učitaj ispravne vrijednosti u centima iz tablice ...
icent 	= 		icent1 + (ioct * 1200); i preslikaj u ispravnu oktavu
ifreq 	= 		itunfreq * cent(icent); izračunaj frekvenciju
;anote	oscils	ivel, ifreq, 0
;kenv		linsegr	0, .1, 1, p3-0.1, 1, .1, 0
anote		pluck		ivel, ifreq, ifreq, 0, 3, 1
kenv		expsegr	1, .1, 0.8, 0.5, 0.66,1.0, 0.44, 1.5, 0.3, 2.0, 0.2, 1.5, 0.00001 ;ovojnica signala
anote		=		anote	* kenv
		denorm anote
aL, aR	freeverb anote, anote, 0.5, 0.45, sr, 0 ; prostor
		outs anote + aL, anote + aR

;;ISPIŠI IZLAZNE PODATKE U GRAFIČKO SUČELJE
Skey		sprintf	"%d", ikey
		outvalue	"key", Skey; MIDI tipka
Scale		sprintf	"%d", iscale
		outvalue	"table", Scale; Tablični broj skale
Steps		sprintf	"%d", itablen
		outvalue	"steps", Steps; broj stepena u skali
Sindx		sprintf	"%d", indx
		outvalue	"indx", Sindx; kojem stepenu skale odgovara odsvirana tipka
		outvalue	"cent", icent; relativna visina u centima u odnosu na referentni ton
		outvalue	"freq", ifreq; frekvencija u hercima
endin
</CsInstruments>
<CsScore>
f 0 9999
e
</CsScore>
</CsoundSynthesizer><bsbPanel>
 <label>Widgets</label>
 <objectName/>
 <x>0</x>
 <y>61</y>
 <width>386</width>
 <height>568</height>
 <visible>true</visible>
 <uuid/>
 <bgcolor mode="background">
  <r>88</r>
  <g>126</g>
  <b>91</b>
 </bgcolor>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>key</objectName>
  <x>242</x>
  <y>179</y>
  <width>80</width>
  <height>25</height>
  <uuid>{94a4ad0c-6cee-43c3-819a-2071a398054c}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>70</label>
  <alignment>left</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>66</x>
  <y>179</y>
  <width>174</width>
  <height>27</height>
  <uuid>{a70d4316-edd5-45ed-a674-f01437b49f5a}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>MIDI tipka:</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>indx</objectName>
  <x>244</x>
  <y>270</y>
  <width>80</width>
  <height>25</height>
  <uuid>{9f6f5ad9-49ce-44ae-86f7-b03446bfe9df}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>10</label>
  <alignment>left</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>-1684371923</x>
  <y>-1632653318</y>
  <width>227</width>
  <height>25</height>
  <uuid>{fbfc873e-28ae-4d6b-bde2-9fa06b5ef9cf}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Cent Deviation</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>steps</objectName>
  <x>245</x>
  <y>239</y>
  <width>78</width>
  <height>26</height>
  <uuid>{e7cf9b68-4ef0-43b8-9771-8f9090aa0588}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>12</label>
  <alignment>left</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>13</x>
  <y>237</y>
  <width>225</width>
  <height>27</height>
  <uuid>{2056e6d6-9991-4217-890e-2903ac3ba66e}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Broj stepena u oktavi:</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>cent</objectName>
  <x>246</x>
  <y>299</y>
  <width>78</width>
  <height>31</height>
  <uuid>{79e0067a-193c-4f66-8504-cd4070e79148}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>947.000</label>
  <alignment>left</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>14</x>
  <y>297</y>
  <width>225</width>
  <height>45</height>
  <uuid>{0c6add93-567a-411e-bde7-fbdd053d06d8}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Relativna visina u centima:</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>freq</objectName>
  <x>246</x>
  <y>347</y>
  <width>78</width>
  <height>31</height>
  <uuid>{46a14266-62e2-4e3c-9316-72cfffaa3143}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>452.075</label>
  <alignment>left</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>14</x>
  <y>345</y>
  <width>225</width>
  <height>45</height>
  <uuid>{6b6a9918-2f63-42db-aafc-9b95f730c796}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Frekvencija (Hz):</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>5</x>
  <y>10</y>
  <width>365</width>
  <height>134</height>
  <uuid>{e68449e1-eb41-4924-84e2-79da23a0a081}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>UPIS</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>18</fontsize>
  <precision>3</precision>
  <color>
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </color>
  <bgcolor mode="background">
   <r>82</r>
   <g>118</g>
   <b>86</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>5</x>
  <y>150</y>
  <width>365</width>
  <height>235</height>
  <uuid>{5c2feba2-d34e-45bf-a02a-53c7c8e9e60a}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>ISPIS</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>17</fontsize>
  <precision>3</precision>
  <color>
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </color>
  <bgcolor mode="nobackground">
   <r>87</r>
   <g>125</g>
   <b>90</b>
  </bgcolor>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBSpinBox">
  <objectName>tunfreq</objectName>
  <x>129</x>
  <y>104</y>
  <width>107</width>
  <height>26</height>
  <uuid>{93a0d14d-13dc-44b7-9c15-b9e528481030}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <alignment>left</alignment>
  <font>Lucida Grande</font>
  <fontsize>10</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <resolution>0.00000100</resolution>
  <minimum>-1e+12</minimum>
  <maximum>1e+12</maximum>
  <randomizable group="0">false</randomizable>
  <value>261.625</value>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>121</x>
  <y>46</y>
  <width>123</width>
  <height>31</height>
  <uuid>{d81b5054-d51b-4e33-93ec-2349a7285d8f}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>Visina</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>18</fontsize>
  <precision>3</precision>
  <color>
   <r>189</r>
   <g>158</g>
   <b>58</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>141</x>
  <y>73</y>
  <width>72</width>
  <height>27</height>
  <uuid>{a8b7cb5d-6575-4740-8618-2da7f771ed1a}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>(Hz)</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>cent</objectName>
  <x>-610629723</x>
  <y>-1632653302</y>
  <width>80</width>
  <height>25</height>
  <uuid>{0d86a913-80ca-4f0c-a1d8-5237387e9d7e}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>947.000</label>
  <alignment>left</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>-610629955</x>
  <y>-1632653304</y>
  <width>227</width>
  <height>25</height>
  <uuid>{86c92e79-68a8-472e-9d57-6c28f2e20370}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Cent Deviation</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>14</x>
  <y>268</y>
  <width>225</width>
  <height>27</height>
  <uuid>{68c06eae-a5b3-4bb6-849a-2b43b4a72c54}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Stepen:</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDisplay">
  <objectName>table</objectName>
  <x>241</x>
  <y>208</y>
  <width>80</width>
  <height>25</height>
  <uuid>{aec8b457-6f1f-404e-8b95-811029326b7e}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>14</label>
  <alignment>left</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>65</x>
  <y>208</y>
  <width>174</width>
  <height>27</height>
  <uuid>{9d62aed7-20b4-4806-9ef3-06b09dc8361a}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Skala (Broj tablice):</label>
  <alignment>right</alignment>
  <font>Lucida Grande</font>
  <fontsize>14</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBDropdown">
  <objectName>scale</objectName>
  <x>241</x>
  <y>106</y>
  <width>130</width>
  <height>25</height>
  <uuid>{01e92f12-f0c9-42d9-b60f-6b7809eda42e}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <bsbDropdownItemList>
   <bsbDropdownItem>
    <name>čista</name>
    <value>0</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>pitagorejska</name>
    <value>1</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>srednjetonska</name>
    <value>2</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>Werckmeister3</name>
    <value>3</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>Kirnberger2</name>
    <value>4</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>Bach-Kellner</name>
    <value>5</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>j.t. kromatska</name>
    <value>6</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>j.t. trećinostepena</name>
    <value>7</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>j.t. četvrtstepena</name>
    <value>8</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>indijska šruti</name>
    <value>9</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>Young WTP</name>
    <value>10</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>Johnston </name>
    <value>11</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>Partch</name>
    <value>12</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>slendro/pelog</name>
    <value>13</value>
    <stringvalue/>
   </bsbDropdownItem>
  </bsbDropdownItemList>
  <selectedIndex>13</selectedIndex>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>251</x>
  <y>46</y>
  <width>84</width>
  <height>49</height>
  <uuid>{63159551-4d3b-4c1a-98dd-1fdc69aa2faa}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>Odabir ugodbe</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>18</fontsize>
  <precision>3</precision>
  <color>
   <r>189</r>
   <g>158</g>
   <b>58</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBSpinBox">
  <objectName>reftone</objectName>
  <x>36</x>
  <y>106</y>
  <width>68</width>
  <height>26</height>
  <uuid>{e11c54ed-ecc2-499c-9c6e-2cf4afa18767}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <alignment>left</alignment>
  <font>Lucida Grande</font>
  <fontsize>10</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <resolution>1.00000000</resolution>
  <minimum>-1e+12</minimum>
  <maximum>1e+12</maximum>
  <randomizable group="0">false</randomizable>
  <value>60</value>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>21</x>
  <y>45</y>
  <width>92</width>
  <height>47</height>
  <uuid>{05ad2176-dc62-45e2-be76-9e0b4afbc0cb}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <label>Referentni ton</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>18</fontsize>
  <precision>3</precision>
  <color>
   <r>189</r>
   <g>158</g>
   <b>58</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject version="2" type="BSBLabel">
  <objectName/>
  <x>25</x>
  <y>85</y>
  <width>87</width>
  <height>25</height>
  <uuid>{bb94b75a-bc18-4ba6-9f46-6f2f03bcd91e}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>(Midi-broj)</label>
  <alignment>center</alignment>
  <font>Lucida Grande</font>
  <fontsize>12</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
</bsbPanel>
<bsbPresets>
</bsbPresets>
<MacOptions>
Version: 3
Render: Real
Ask: Yes
Functions: ioObject
Listing: Window
WindowBounds: 0 61 386 568
CurrentView: io
IOViewEdit: On
Options:
</MacOptions>

<MacGUI>
ioView background {22616, 32382, 23387}
ioText {242, 179} {80, 25} display 70.000000 0.00100 "key" left "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 70
ioText {66, 179} {174, 27} label 0.000000 0.00100 "" right "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder MIDI tipka:
ioText {244, 270} {80, 25} display 10.000000 0.00100 "indx" left "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 10
ioText {-1684371923, -1632653318} {227, 25} label 0.000000 0.00100 "" right "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder Cent Deviation
ioText {245, 239} {78, 26} display 12.000000 0.00100 "steps" left "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 12
ioText {13, 237} {225, 27} label 0.000000 0.00100 "" right "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder Broj stepena u oktavi:
ioText {246, 299} {78, 31} display 947.000000 0.00100 "cent" left "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 947.000
ioText {14, 297} {225, 45} label 0.000000 0.00100 "" right "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder Relativna visina u centima:
ioText {246, 347} {78, 31} display 452.075256 0.00100 "freq" left "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 452.075
ioText {14, 345} {225, 45} label 0.000000 0.00100 "" right "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder Frekvencija (Hz):
ioText {5, 10} {365, 134} label 0.000000 0.00100 "" center "Lucida Grande" 18 {65280, 65280, 65280} {20992, 30208, 22016} nobackground noborder UPIS
ioText {5, 150} {365, 235} label 0.000000 0.00100 "" center "Lucida Grande" 17 {65280, 65280, 65280} {65280, 65280, 65280} nobackground noborder ISPIS
ioText {129, 104} {107, 26} editnum 261.625000 0.000001 "tunfreq" left "" 0 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 261.625000
ioText {121, 46} {123, 31} label 0.000000 0.00100 "" center "Lucida Grande" 18 {48384, 40448, 14848} {65280, 65280, 65280} nobackground noborder Visina
ioText {141, 73} {72, 27} label 0.000000 0.00100 "" center "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder (Hz)
ioText {-610629723, -1632653302} {80, 25} display 947.000000 0.00100 "cent" left "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 947.000
ioText {-610629955, -1632653304} {227, 25} label 0.000000 0.00100 "" right "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder Cent Deviation
ioText {14, 268} {225, 27} label 0.000000 0.00100 "" right "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder Stepen:
ioText {241, 208} {80, 25} display 14.000000 0.00100 "table" left "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 14
ioText {65, 208} {174, 27} label 0.000000 0.00100 "" right "Lucida Grande" 14 {0, 0, 0} {65280, 65280, 65280} nobackground noborder Skala (Broj tablice):
ioMenu {241, 106} {130, 25} 13 303 "čista,pitagorejska,srednjetonska,Werckmeister3,Kirnberger2,Bach-Kellner,j.t. kromatska,j.t. trećinostepena,j.t. četvrtstepena,indijska šruti,Young WTP,Johnston ,Partch,slendro/pelog" scale
ioText {251, 46} {84, 49} label 0.000000 0.00100 "" center "Lucida Grande" 18 {48384, 40448, 14848} {65280, 65280, 65280} nobackground noborder Odabir ugodbe
ioText {36, 106} {68, 26} editnum 60.000000 1.000000 "reftone" left "" 0 {0, 0, 0} {65280, 65280, 65280} nobackground noborder 60.000000
ioText {21, 45} {92, 47} label 0.000000 0.00100 "" center "Lucida Grande" 18 {48384, 40448, 14848} {65280, 65280, 65280} nobackground noborder Referentni ton
ioText {25, 85} {87, 25} label 0.000000 0.00100 "" center "Lucida Grande" 12 {0, 0, 0} {65280, 65280, 65280} nobackground noborder (Midi-broj)
</MacGUI>
